/****************************************************************************
** Meta object code from reading C++ file 'kglobalaccel_component_interface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "kglobalaccel_component_interface.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kglobalaccel_component_interface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN36OrgKdeKglobalaccelComponentInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgKdeKglobalaccelComponentInterface::qt_create_metaobjectdata<qt_meta_tag_ZN36OrgKdeKglobalaccelComponentInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgKdeKglobalaccelComponentInterface",
        "globalShortcutPressed",
        "",
        "componentUnique",
        "actionUnique",
        "timestamp",
        "globalShortcutReleased",
        "globalShortcutRepeated",
        "allShortcutInfos",
        "QDBusPendingReply<QList<KGlobalShortcutInfo>>",
        "context",
        "cleanUp",
        "QDBusPendingReply<bool>",
        "getShortcutContexts",
        "QDBusPendingReply<QStringList>",
        "invokeShortcut",
        "QDBusPendingReply<>",
        "actionName",
        "isActive",
        "shortcutNames",
        "friendlyName",
        "uniqueName"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'globalShortcutPressed'
        QtMocHelpers::SignalData<void(const QString &, const QString &, qlonglong)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 }, { QMetaType::LongLong, 5 },
        }}),
        // Signal 'globalShortcutReleased'
        QtMocHelpers::SignalData<void(const QString &, const QString &, qlonglong)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 }, { QMetaType::LongLong, 5 },
        }}),
        // Signal 'globalShortcutRepeated'
        QtMocHelpers::SignalData<void(const QString &, const QString &, qlonglong)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 }, { QMetaType::LongLong, 5 },
        }}),
        // Slot 'allShortcutInfos'
        QtMocHelpers::SlotData<QDBusPendingReply<QList<KGlobalShortcutInfo> >()>(8, 2, QMC::AccessPublic, 0x80000000 | 9),
        // Slot 'allShortcutInfos'
        QtMocHelpers::SlotData<QDBusPendingReply<QList<KGlobalShortcutInfo> >(const QString &)>(8, 2, QMC::AccessPublic, 0x80000000 | 9, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'cleanUp'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>()>(11, 2, QMC::AccessPublic, 0x80000000 | 12),
        // Slot 'getShortcutContexts'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>()>(13, 2, QMC::AccessPublic, 0x80000000 | 14),
        // Slot 'invokeShortcut'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(15, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::QString, 17 },
        }}),
        // Slot 'isActive'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>()>(18, 2, QMC::AccessPublic, 0x80000000 | 12),
        // Slot 'shortcutNames'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>()>(19, 2, QMC::AccessPublic, 0x80000000 | 14),
        // Slot 'shortcutNames'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>(const QString &)>(19, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { QMetaType::QString, 10 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'friendlyName'
        QtMocHelpers::PropertyData<QString>(20, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'uniqueName'
        QtMocHelpers::PropertyData<QString>(21, QMetaType::QString, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgKdeKglobalaccelComponentInterface, qt_meta_tag_ZN36OrgKdeKglobalaccelComponentInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgKdeKglobalaccelComponentInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN36OrgKdeKglobalaccelComponentInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN36OrgKdeKglobalaccelComponentInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN36OrgKdeKglobalaccelComponentInterfaceE_t>.metaTypes,
    nullptr
} };

void OrgKdeKglobalaccelComponentInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgKdeKglobalaccelComponentInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->globalShortcutPressed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[3]))); break;
        case 1: _t->globalShortcutReleased((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[3]))); break;
        case 2: _t->globalShortcutRepeated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[3]))); break;
        case 3: { QDBusPendingReply<QList<KGlobalShortcutInfo>> _r = _t->allShortcutInfos();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QList<KGlobalShortcutInfo>>*>(_a[0]) = std::move(_r); }  break;
        case 4: { QDBusPendingReply<QList<KGlobalShortcutInfo>> _r = _t->allShortcutInfos((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QList<KGlobalShortcutInfo>>*>(_a[0]) = std::move(_r); }  break;
        case 5: { QDBusPendingReply<bool> _r = _t->cleanUp();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 6: { QDBusPendingReply<QStringList> _r = _t->getShortcutContexts();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 7: { QDBusPendingReply<> _r = _t->invokeShortcut((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 8: { QDBusPendingReply<bool> _r = _t->isActive();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 9: { QDBusPendingReply<QStringList> _r = _t->shortcutNames();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 10: { QDBusPendingReply<QStringList> _r = _t->shortcutNames((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKglobalaccelComponentInterface::*)(const QString & , const QString & , qlonglong )>(_a, &OrgKdeKglobalaccelComponentInterface::globalShortcutPressed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKglobalaccelComponentInterface::*)(const QString & , const QString & , qlonglong )>(_a, &OrgKdeKglobalaccelComponentInterface::globalShortcutReleased, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKglobalaccelComponentInterface::*)(const QString & , const QString & , qlonglong )>(_a, &OrgKdeKglobalaccelComponentInterface::globalShortcutRepeated, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->friendlyName(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->uniqueName(); break;
        default: break;
        }
    }
}

const QMetaObject *OrgKdeKglobalaccelComponentInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgKdeKglobalaccelComponentInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN36OrgKdeKglobalaccelComponentInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgKdeKglobalaccelComponentInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void OrgKdeKglobalaccelComponentInterface::globalShortcutPressed(const QString & _t1, const QString & _t2, qlonglong _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void OrgKdeKglobalaccelComponentInterface::globalShortcutReleased(const QString & _t1, const QString & _t2, qlonglong _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 2
void OrgKdeKglobalaccelComponentInterface::globalShortcutRepeated(const QString & _t1, const QString & _t2, qlonglong _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3);
}
QT_WARNING_POP
