/****************************************************************************
** Meta object code from reading C++ file 'kglobalaccel_interface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "kglobalaccel_interface.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kglobalaccel_interface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN27OrgKdeKGlobalAccelInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgKdeKGlobalAccelInterface::qt_create_metaobjectdata<qt_meta_tag_ZN27OrgKdeKGlobalAccelInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgKdeKGlobalAccelInterface",
        "yourShortcutGotChanged",
        "Q_DECL_DEPRECATED",
        "actionId",
        "QList<int>",
        "newKeys",
        "yourShortcutsChanged",
        "",
        "QList<QKeySequence>",
        "action",
        "QDBusPendingReply<QStringList>",
        "key",
        "actionList",
        "QKeySequence",
        "activateGlobalShortcutContext",
        "QDBusPendingReply<>",
        "component",
        "context",
        "allActionsForComponent",
        "QDBusPendingReply<QList<QStringList>>",
        "allComponents",
        "QDBusPendingReply<QList<QDBusObjectPath>>",
        "allMainComponents",
        "blockGlobalShortcuts",
        "in0",
        "defaultShortcut",
        "QDBusPendingReply<QList<int>>",
        "defaultShortcutKeys",
        "QDBusPendingReply<QList<QKeySequence>>",
        "doRegister",
        "getComponent",
        "QDBusPendingReply<QDBusObjectPath>",
        "componentUnique",
        "getGlobalShortcutsByKey",
        "QDBusPendingReply<QList<KGlobalShortcutInfo>>",
        "globalShortcutAvailable",
        "QDBusPendingReply<bool>",
        "globalShortcutsByKey",
        "KGlobalAccel::MatchType",
        "matchType",
        "isGlobalShortcutAvailable",
        "setForeignShortcut",
        "keys",
        "setForeignShortcutKeys",
        "setInactive",
        "setInverseShortcutActions",
        "forwardActionUnique",
        "backwardActionUnique",
        "flags",
        "setShortcut",
        "setShortcutKeys",
        "shortcut",
        "shortcutKeys",
        "unRegister",
        "unregister",
        "shortcutUnique"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'yourShortcutGotChanged'
        QtMocHelpers::SignalData<void(const QStringList &, const QList<int> &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 3 }, { 0x80000000 | 4, 5 },
        }}),
        // Signal 'yourShortcutsChanged'
        QtMocHelpers::SignalData<void(const QStringList &, const QList<QKeySequence> &)>(6, 7, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 3 }, { 0x80000000 | 8, 5 },
        }}),
        // Slot 'action'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>(int)>(9, 2, QMC::AccessPublic, 0x80000000 | 10, {{
            { QMetaType::Int, 11 },
        }}),
        // Slot 'actionList'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>(const QKeySequence &)>(12, 2, QMC::AccessPublic, 0x80000000 | 10, {{
            { 0x80000000 | 13, 11 },
        }}),
        // Slot 'activateGlobalShortcutContext'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &)>(14, 7, QMC::AccessPublic, 0x80000000 | 15, {{
            { QMetaType::QString, 16 }, { QMetaType::QString, 17 },
        }}),
        // Slot 'allActionsForComponent'
        QtMocHelpers::SlotData<QDBusPendingReply<QList<QStringList> >(const QStringList &)>(18, 7, QMC::AccessPublic, 0x80000000 | 19, {{
            { QMetaType::QStringList, 3 },
        }}),
        // Slot 'allComponents'
        QtMocHelpers::SlotData<QDBusPendingReply<QList<QDBusObjectPath> >()>(20, 7, QMC::AccessPublic, 0x80000000 | 21),
        // Slot 'allMainComponents'
        QtMocHelpers::SlotData<QDBusPendingReply<QList<QStringList> >()>(22, 7, QMC::AccessPublic, 0x80000000 | 19),
        // Slot 'blockGlobalShortcuts'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(23, 7, QMC::AccessPublic, 0x80000000 | 15, {{
            { QMetaType::Bool, 24 },
        }}),
        // Slot 'defaultShortcut'
        QtMocHelpers::SlotData<QDBusPendingReply<QList<int> >(const QStringList &)>(25, 2, QMC::AccessPublic, 0x80000000 | 26, {{
            { QMetaType::QStringList, 3 },
        }}),
        // Slot 'defaultShortcutKeys'
        QtMocHelpers::SlotData<QDBusPendingReply<QList<QKeySequence> >(const QStringList &)>(27, 7, QMC::AccessPublic, 0x80000000 | 28, {{
            { QMetaType::QStringList, 3 },
        }}),
        // Slot 'doRegister'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QStringList &)>(29, 7, QMC::AccessPublic, 0x80000000 | 15, {{
            { QMetaType::QStringList, 3 },
        }}),
        // Slot 'getComponent'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusObjectPath>(const QString &)>(30, 7, QMC::AccessPublic, 0x80000000 | 31, {{
            { QMetaType::QString, 32 },
        }}),
        // Slot 'getGlobalShortcutsByKey'
        QtMocHelpers::SlotData<QDBusPendingReply<QList<KGlobalShortcutInfo> >(int)>(33, 7, QMC::AccessPublic, 0x80000000 | 34, {{
            { QMetaType::Int, 11 },
        }}),
        // Slot 'globalShortcutAvailable'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(const QKeySequence &, const QString &)>(35, 7, QMC::AccessPublic, 0x80000000 | 36, {{
            { 0x80000000 | 13, 11 }, { QMetaType::QString, 16 },
        }}),
        // Slot 'globalShortcutsByKey'
        QtMocHelpers::SlotData<QDBusPendingReply<QList<KGlobalShortcutInfo> >(const QKeySequence &, KGlobalAccel::MatchType)>(37, 7, QMC::AccessPublic, 0x80000000 | 34, {{
            { 0x80000000 | 13, 11 }, { 0x80000000 | 38, 39 },
        }}),
        // Slot 'isGlobalShortcutAvailable'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(int, const QString &)>(40, 7, QMC::AccessPublic, 0x80000000 | 36, {{
            { QMetaType::Int, 11 }, { QMetaType::QString, 16 },
        }}),
        // Slot 'setForeignShortcut'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QStringList &, const QList<int> &)>(41, 2, QMC::AccessPublic, 0x80000000 | 15, {{
            { QMetaType::QStringList, 3 }, { 0x80000000 | 4, 42 },
        }}),
        // Slot 'setForeignShortcutKeys'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QStringList &, const QList<QKeySequence> &)>(43, 7, QMC::AccessPublic, 0x80000000 | 15, {{
            { QMetaType::QStringList, 3 }, { 0x80000000 | 8, 42 },
        }}),
        // Slot 'setInactive'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QStringList &)>(44, 7, QMC::AccessPublic, 0x80000000 | 15, {{
            { QMetaType::QStringList, 3 },
        }}),
        // Slot 'setInverseShortcutActions'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(const QString &, const QString &, const QString &, uint)>(45, 7, QMC::AccessPublic, 0x80000000 | 36, {{
            { QMetaType::QString, 32 }, { QMetaType::QString, 46 }, { QMetaType::QString, 47 }, { QMetaType::UInt, 48 },
        }}),
        // Slot 'setShortcut'
        QtMocHelpers::SlotData<QDBusPendingReply<QList<int> >(const QStringList &, const QList<int> &, uint)>(49, 2, QMC::AccessPublic, 0x80000000 | 26, {{
            { QMetaType::QStringList, 3 }, { 0x80000000 | 4, 42 }, { QMetaType::UInt, 48 },
        }}),
        // Slot 'setShortcutKeys'
        QtMocHelpers::SlotData<QDBusPendingReply<QList<QKeySequence> >(const QStringList &, const QList<QKeySequence> &, uint)>(50, 7, QMC::AccessPublic, 0x80000000 | 28, {{
            { QMetaType::QStringList, 3 }, { 0x80000000 | 8, 42 }, { QMetaType::UInt, 48 },
        }}),
        // Slot 'shortcut'
        QtMocHelpers::SlotData<QDBusPendingReply<QList<int> >(const QStringList &)>(51, 2, QMC::AccessPublic, 0x80000000 | 26, {{
            { QMetaType::QStringList, 3 },
        }}),
        // Slot 'shortcutKeys'
        QtMocHelpers::SlotData<QDBusPendingReply<QList<QKeySequence> >(const QStringList &)>(52, 7, QMC::AccessPublic, 0x80000000 | 28, {{
            { QMetaType::QStringList, 3 },
        }}),
        // Slot 'unRegister'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QStringList &)>(53, 2, QMC::AccessPublic, 0x80000000 | 15, {{
            { QMetaType::QStringList, 3 },
        }}),
        // Slot 'unregister'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(const QString &, const QString &)>(54, 7, QMC::AccessPublic, 0x80000000 | 36, {{
            { QMetaType::QString, 32 }, { QMetaType::QString, 55 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgKdeKGlobalAccelInterface, qt_meta_tag_ZN27OrgKdeKGlobalAccelInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgKdeKGlobalAccelInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27OrgKdeKGlobalAccelInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27OrgKdeKGlobalAccelInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN27OrgKdeKGlobalAccelInterfaceE_t>.metaTypes,
    nullptr
} };

void OrgKdeKGlobalAccelInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgKdeKGlobalAccelInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->yourShortcutGotChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[2]))); break;
        case 1: _t->yourShortcutsChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QKeySequence>>>(_a[2]))); break;
        case 2: { QDBusPendingReply<QStringList> _r = _t->action((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 3: { QDBusPendingReply<QStringList> _r = _t->actionList((*reinterpret_cast<std::add_pointer_t<QKeySequence>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 4: { QDBusPendingReply<> _r = _t->activateGlobalShortcutContext((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 5: { QDBusPendingReply<QList<QStringList>> _r = _t->allActionsForComponent((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QList<QStringList>>*>(_a[0]) = std::move(_r); }  break;
        case 6: { QDBusPendingReply<QList<QDBusObjectPath>> _r = _t->allComponents();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QList<QDBusObjectPath>>*>(_a[0]) = std::move(_r); }  break;
        case 7: { QDBusPendingReply<QList<QStringList>> _r = _t->allMainComponents();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QList<QStringList>>*>(_a[0]) = std::move(_r); }  break;
        case 8: { QDBusPendingReply<> _r = _t->blockGlobalShortcuts((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 9: { QDBusPendingReply<QList<int>> _r = _t->defaultShortcut((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QList<int>>*>(_a[0]) = std::move(_r); }  break;
        case 10: { QDBusPendingReply<QList<QKeySequence>> _r = _t->defaultShortcutKeys((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QList<QKeySequence>>*>(_a[0]) = std::move(_r); }  break;
        case 11: { QDBusPendingReply<> _r = _t->doRegister((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 12: { QDBusPendingReply<QDBusObjectPath> _r = _t->getComponent((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 13: { QDBusPendingReply<QList<KGlobalShortcutInfo>> _r = _t->getGlobalShortcutsByKey((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QList<KGlobalShortcutInfo>>*>(_a[0]) = std::move(_r); }  break;
        case 14: { QDBusPendingReply<bool> _r = _t->globalShortcutAvailable((*reinterpret_cast<std::add_pointer_t<QKeySequence>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 15: { QDBusPendingReply<QList<KGlobalShortcutInfo>> _r = _t->globalShortcutsByKey((*reinterpret_cast<std::add_pointer_t<QKeySequence>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KGlobalAccel::MatchType>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QList<KGlobalShortcutInfo>>*>(_a[0]) = std::move(_r); }  break;
        case 16: { QDBusPendingReply<bool> _r = _t->isGlobalShortcutAvailable((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 17: { QDBusPendingReply<> _r = _t->setForeignShortcut((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 18: { QDBusPendingReply<> _r = _t->setForeignShortcutKeys((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QKeySequence>>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 19: { QDBusPendingReply<> _r = _t->setInactive((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 20: { QDBusPendingReply<bool> _r = _t->setInverseShortcutActions((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 21: { QDBusPendingReply<QList<int>> _r = _t->setShortcut((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QList<int>>*>(_a[0]) = std::move(_r); }  break;
        case 22: { QDBusPendingReply<QList<QKeySequence>> _r = _t->setShortcutKeys((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QKeySequence>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QList<QKeySequence>>*>(_a[0]) = std::move(_r); }  break;
        case 23: { QDBusPendingReply<QList<int>> _r = _t->shortcut((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QList<int>>*>(_a[0]) = std::move(_r); }  break;
        case 24: { QDBusPendingReply<QList<QKeySequence>> _r = _t->shortcutKeys((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QList<QKeySequence>>*>(_a[0]) = std::move(_r); }  break;
        case 25: { QDBusPendingReply<> _r = _t->unRegister((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 26: { QDBusPendingReply<bool> _r = _t->unregister((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKGlobalAccelInterface::*)(const QStringList & , const QList<int> & )>(_a, &OrgKdeKGlobalAccelInterface::yourShortcutGotChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKGlobalAccelInterface::*)(const QStringList & , const QList<QKeySequence> & )>(_a, &OrgKdeKGlobalAccelInterface::yourShortcutsChanged, 1))
            return;
    }
}

const QMetaObject *OrgKdeKGlobalAccelInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgKdeKGlobalAccelInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27OrgKdeKGlobalAccelInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgKdeKGlobalAccelInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 27)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 27;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 27)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 27;
    }
    return _id;
}

// SIGNAL 0
void OrgKdeKGlobalAccelInterface::yourShortcutGotChanged(const QStringList & _t1, const QList<int> & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void OrgKdeKGlobalAccelInterface::yourShortcutsChanged(const QStringList & _t1, const QList<QKeySequence> & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}
QT_WARNING_POP
